Page 62 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 62

Home

    When the Constitutional Convention was on the verge
    of breaking up, Benjamin Franklin stood up and made a
    motion stating:

    In the beginning of the contest with Britain, when we
    were sensible of danger, we had daily prayers in this
    room for the divine protection. Our prayers, Sir, were
    heard — and they were graciously answered. . . .

    I therefore beg leave to move that, henceforth,
    prayers imploring the assistance of heaven and its
    blessings on our deliberations be held in this assembly
    every morning before we proceed to business, and that
    one or more of the clergy of this city be requested to
    officiate in that service.

    The record is replete with examples of the Founding
    Fathers' reliance on, and thankfulness for, Divine

    It may be far more than just a coincidence that the
    founding of the Illuminati and the founding of the
    American Republic both took place in 1776. For over a

    hundred years, the Republic stood as a roadblock to
    Weishaupt's scheme for his Order to rule the world.
    During this period, the American Republic was a shining
    example of everything that was contrary to what the
    Illuminati and its followers were bringing upon the

    world. Out of this difference has come a protracted
    struggle between good and evil, freedom and slavery,
    which has continued throughout the twentieth century.
    To understand better why the Founding Fathers
    established the kind of government that they did, it is

    57

    The American Republic

    assistance.